import posthog
import uuid
import sys
import os
from chromadb.server.utils.telemetry import Telemetry
from chromadb import get_settings

class Capture(Telemetry):
    _conn = None
    _telemetry_anonymized_uuid = None

    def __init__(self):
        if get_settings().disable_anonymized_telemetry:
            posthog.disabled = True

        # disable telemetry if we're running tests
        if "pytest" in sys.modules:
            posthog.disabled = True

        posthog.project_api_key = 'phc_YeUxaojbKk5KPi8hNlx1bBKHzuZ4FDtl67kH1blv8Bh'
        posthog.host = 'https://app.posthog.com'
        self._conn = posthog

        if not get_settings().telemetry_anonymized_uuid:
            self._telemetry_anonymized_uuid = uuid.uuid4()

            with open(".env", "a") as f:
                f.write(f"\ntelemetry_anonymized_uuid={self._telemetry_anonymized_uuid}\n")

        else:
            self._telemetry_anonymized_uuid = get_settings().telemetry_anonymized_uuid

    def capture(self, event, properties=None):
        if properties is None:
            properties = {}

        properties['environment'] = os.getenv('environment', 'development')

        self._conn.capture(self._telemetry_anonymized_uuid, event, properties)



from chromadb import get_settings

import sentry_sdk
from sentry_sdk.client import Client
from sentry_sdk import configure_scope
from posthog.sentry.posthog_integration import PostHogIntegration
PostHogIntegration.organization = "chroma"
sample_rate = 1.0
if get_settings().environment == "production":
    sample_rate = 0.1

def strip_sensitive_data(event, hint):
    if 'server_name' in event:
        del event['server_name']
        return event

def init_error_reporting():

    if get_settings().environment == "test":
        return

    sentry_sdk.init(
        dsn="https://ef5fae1e461f49b3a7a2adf3404378ab@o4504080408051712.ingest.sentry.io/4504080409296896",
        traces_sample_rate=sample_rate,
        integrations=[PostHogIntegration()],
        environment=get_settings().environment,
        before_send=strip_sensitive_data,
    )
    with configure_scope() as scope:
        scope.set_tag('posthog_distinct_id', get_settings().telemetry_anonymized_uuid)



from abc import ABC, abstractmethod

#from chroma.utils.error_reporting import init_error_reporting
from chromadb.server.utils.telemetry.capture import Capture

class Server(ABC):

    def __init__(self, settings):
        pass
        # init_error_reporting()
